Introduction — Bloxone API Wrapper 0.6.1 documentation

# Introduction

The Infoblox BloxOne suite of applications provides a RESTful API that is published using Swagger on https://docs.infoblox.com/apidoc along with other Infoblox APIs.

This module aims to provide a class hierarchy to simplify access to these published APIs, performing the ‘heavy lifting’ whilst providing full access to to their functionality. This is achieved by providing simple wrappers that enable you to take the swagger documented object paths, fields and where appropriate JSON body from the documentation and pass them to simple get, create, delete and update methods. These methods simply return a `requests` response object.

In addition, useful utility methods are provided for common tasks such as getting an object id, by defining the object key and value match pair. Or getting a threat feed from TIDE. This is combined with several (currently) undocumented API calls and some data validation/normalisation functions.

Some basic configuration, such a base url, API version and API key are read from an ini file. An example of which is provided. When instantiating/initialising this will read config.ini by default. Alternatively a path can be provided.